<?php

namespace Litecms\Blacklist\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Litecms\Blacklist\Models\Blacklist;


class BlacklistAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Blacklist $blacklist, array $request = [])
    {
        $this->model = $blacklist;

        $function = Str::camel($action);
        event('litecms.blacklist.blacklist.action.' . $action . 'ing', [$blacklist]);
        $data =  $this->$function($blacklist, $request);
        event('litecms.blacklist.blacklist.action.' . $action . 'ed', [$blacklist]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Blacklist $blacklist, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $blacklist = $blacklist->create($attributes);
        return $blacklist;
    }

    public function update(Blacklist $blacklist, array $request)
    {
        $attributes = $request;
        $blacklist->update($attributes);
        return $blacklist;
    }

    public function destroy(Blacklist $blacklist, array $request)
    {
        $blacklist->delete();
        return $blacklist;
    }

    public function copy(Blacklist $blacklist, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $blacklist = $blacklist->replicate();
            $blacklist->created_at = Carbon::now();
            $blacklist->save();
            return $blacklist;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $blacklist->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $blacklist;
    }


}
