<?php

namespace Litecms\Blacklist\Actions;

use Illuminate\Support\Str;
use Litecms\Blacklist\Models\Blacklist;
use Litecms\Blacklist\Scopes\BlacklistResourceScope;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Database\RequestScope;

class BlacklistActions
{
    use AsAction;
    use LogsActions;
    
    private $model;

    public function handle(string $action, array $request)
    {
        $this->model = app(Blacklist::class);

        $function = Str::camel($action);

        event('litecms.blacklist.blacklist.action.' . $action . 'ing', [$request]);
        $data = $this->$function($request);
        event('litecms.blacklist.blacklist.action.' . $action . 'ed', [$data]);

        $this->logsAction();
        return $data;

    }

    public function paginate(array $request)
    {
        $pageLimit = isset($request['pageLimit']) ?: config('database.pagination.limit');
        $blacklist = $this->model
            ->pushScope(new RequestScope())
            ->pushScope(new BlacklistResourceScope())
            ->paginate($pageLimit);

        return $blacklist;
    }

    public function simplePaginate(array $request)
    {
        $pageLimit = isset($request['pageLimit']) ?: config('database.pagination.limit');
        $blacklist = $this->model
            ->pushScope(new RequestScope())
            ->pushScope(new BlacklistResourceScope())
            ->simplePaginate($pageLimit);

        return $blacklist;
    }

    function empty(array $request) {
        return $this->model->forceDelete();
    }

    function restore(array $request) {
        return $this->model->restore();
    }

    public function delete(array $request)
    {
        $ids = $request['ids'];
        $ids = collect($ids)->map(function ($id) {
            return hashids_decode($id);
        });
        return $this->model->whereIn('id', $ids)->delete();
    }
}
