<?php

namespace Litecms\Blacklist\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Blacklist\Actions\BlacklistAction;
use Litecms\Blacklist\Http\Requests\BlacklistActionRequest;
use Litecms\Blacklist\Http\Resources\BlacklistResource;
use Litecms\Blacklist\Models\Blacklist;

/**
 * Admin web controller class.
 */
class BlacklistActionController extends BaseController
{

    /**
     * Action controller function for blacklist.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(BlacklistActionRequest $request, Blacklist $blacklist, $action)
    {
        try {
            $blacklist = BlacklistAction::run($request, $blacklist, $action);

            $data = new BlacklistResource($blacklist);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('blacklist::blacklist.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('blacklist/blacklist/' . $blacklist->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('blacklist/blacklist/' . $blacklist->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
