<?php

namespace Litecms\Blacklist\Http\Controllers;

use Exception;
use Litecms\Blacklist\Actions\BlacklistWorkflow;
use Litecms\Blacklist\Http\Requests\BlacklistWorkflowRequest;
use Litecms\Blacklist\Http\Resources\BlacklistResource;
use Litecms\Blacklist\Models\Blacklist;
use Litepie\Http\Controllers\ActionController as BaseController;

/**
 * Workflow controller class.
 *
 */
class BlacklistWorkflowController extends BaseController
{
    /**
     * Action controller function for blacklist.
     *
     * @param Model $blacklist
     * @param action next action for the blacklist.
     *
     * @return Response
     */
    public function __invoke(BlacklistWorkflowRequest $request, Blacklist $blacklist, $trasition)
    {
        try {
            $blacklist = BlacklistWorkflow::run($request, $blacklist, $trasition);
            $data = new BlacklistResource($blacklist);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('blacklist::blacklist.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('blacklist/blacklist/' . $blacklist->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('blacklist/blacklist/' . $blacklist->getRouteKey()))
                ->redirect();
        }
    }
}
