<?php
namespace Litecms\Blacklist\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Blacklist\Events\BlacklistAction as BlacklistActionEvent;
use Litecms\Blacklist\Models\Blacklist;

class BlacklistAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $blacklist;

    protected $action;

    /**
     * Create a new notification instance.
     *
     * @param BlacklistActionEvent $blacklist
     * @param string $action
     */
    public function __construct(BlacklistActionEvent $blacklist, string $action)
    {
        $this->action = $action;
        $this->blacklist = $blacklist;
    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Blacklist Approved - ' . config('app.name'))
            ->view('blacklist::blacklist.email.action', ['data' => $this->blacklist]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
