<?php

namespace Litecms\Blacklist\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Blacklist\Models\Blacklist;

class BlacklistPolicy
{

    use BlacklistAction;
    use BlacklistWorkflow;

    /**
     * Determine if the given user can view the blacklist.
     *
     * @param UserPolicyInterface $authUser
     * @param Blacklist $blacklist
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Blacklist $blacklist)
    {
        if ($authUser->canDo('blacklist.blacklist.view') && $authUser->isAdmin()) {
            return true;
        }

        return $blacklist->user_id == user_id() && $blacklist->user_type == user_type();
    }

    /**
     * Determine if the given user can create a blacklist.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('blacklist.blacklist.create');
    }

    /**
     * Determine if the given user can update the given blacklist.
     *
     * @param UserPolicyInterface $authUser
     * @param Blacklist $blacklist
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Blacklist $blacklist)
    {
        if ($authUser->canDo('blacklist.blacklist.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $blacklist->user_id == user_id() && $blacklist->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given blacklist.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Blacklist $blacklist)
    {
        return $blacklist->user_id == user_id() && $blacklist->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given blacklist.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Blacklist $blacklist)
    {
        if ($authUser->canDo('blacklist.blacklist.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given blacklist.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Blacklist $blacklist)
    {
        if ($authUser->canDo('blacklist.blacklist.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
